'use strict';

/**
 * @param  {String[]|String} values
 *
 * @return {String[]}
 */

function resolveValues(values) {

	if (Array.isArray(values)) {
		return values;
	}

	return values.split(' ').map(function (value) {
		return value.trim();
	}).filter(function (value) {
		return value !== '';
	});
}

/**
 * @param  {Object|DOMTokenList} classList
 *
 * @return {Object}
 */
module.exports = function (classList) {

	if (typeof classList.add === 'undefined' && typeof classList.remove === 'undefined') {
		throw new Error('`add` and `remove` methods are undefined');
	}

	return {
		add: function (values) {
			resolveValues(values).forEach(function (value) {
				classList.add(value);
			});
		},
		remove: function (values) {
			resolveValues(values).forEach(function (value) {
				classList.remove(value);
			});
		}
	};
};